BarcodePlugin class

Annotations
  • @Deprecated('This is for backwards compatibility, use [BarcodeConfig] instead')

Constructors

BarcodePlugin({AimType aimType = AimType.trigger, int timeoutBetweenScans = 0, List<BarcodeLabelType>? disabledBarcodes, List<BarcodeLabelType>? enabledBarcodes})

Properties

aimType → AimType
final
disabledBarcodes → List<BarcodeLabelType>?
final
enabledBarcodes → List<BarcodeLabelType>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeoutBetweenScans → int
final
toMap → Map<String, dynamic>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fetchDecoderName(BarcodeLabelType barcodeLabelType) → String