ProfileModel class

ProfileModel class This generic class has the settings for the basic scanprofile This can be extended with the hardware specific profiles like HoneywellProfileModel or ZebraProfileModel It's no problem sending a hardware specific profile to a different hardware, the settings that are not supported will be ignored ! For DataLogic devices the length min/max is inherited from previous setup so if this is not set for the codetype used it will use the previously set length if any. You can set min/max length to 0 and it will set no length check for that specific codetype ! Setting this to 0 will have consequences for other hardware manufacturers so be carefull with this. But only use this for the allowed codetypes (not tested that all these works): 1D: Code 128, Code 39, I2of5, Codabar, Matrix 2 of 5, MSI, and Discrete 2 of 5 2D: Data Matrix, QR Code, Aztec Code, PDF417, Micro PDF417

Implementers

Constructors

ProfileModel({required String profileName, List<BarcodeConfig>? enabledBarcodes, bool keepDefaults = true})
ProfileModel.fromMap(Map<String, dynamic> map)
factory

Properties

customMap Map<String, dynamic>?
no setter
enabledBarcodes List<BarcodeConfig>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
keepDefaults bool
getter/setter pair
profileName String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toMap Map<String, dynamic>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited