ScanResult class

Constructors

ScanResult({required String barcode, required BarcodeTypes barcodeType, required String hardwareLabelType})
ScanResult.fromDatawedge(dynamic json)
factory

Properties

barcode → String
final
barcodeType → BarcodeTypes
final
hardwareLabelType → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? barcode, BarcodeTypes? barcodeType, String? hardwareLabelType}) → ScanResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited