HoneywellProfileModel class
This class extends the ProfileModel class
enableEanCheckDigitTransmission allows the last (13th) digit of an EAN-13 to be sent to with the barcode data
ProfileModel class
This generic class has the settings for the basic scanprofile
This can be extended with the hardware specific profiles like HoneywellProfileModel or ZebraProfileModel
It's no problem sending a hardware specific profile to a different hardware, the settings that are not supported will be ignored
! For DataLogic devices the length min/max is inherited from previous setup so if this is not set for the codetype used it will use
the previously set length if any. You can set min/max length to 0 and it will set no length check for that specific codetype
! Setting this to 0 will have consequences for other hardware manufacturers so be carefull with this.
But only use this for the allowed codetypes (not tested that all these works):
1D: Code 128, Code 39, I2of5, Codabar, Matrix 2 of 5, MSI, and Discrete 2 of 5
2D: Data Matrix, QR Code, Aztec Code, PDF417, Micro PDF417
ZebraProfileModel class
This class extends the ProfileModel class
aimType can be set to different AimType like trigger or continuous
enableKeyStroke can be set to true if you want it to send the barcode to the input field, false is default